==> vue-components-1.5.19.tgz: package/lib/modals/src/ModalHeader.vue.rd.js <==
import { defineComponent as a, openBlock as o, createElementBlock as l, renderSlot as s, normalizeClass as i, createBlock as m, unref as d, withCtx as p, createCommentVNode as r, createElementVNode as c } from "vue";
import "../../buttons/index.rd.js";
import { modalHeaderProps as u } from "./props.rd.js";
import f from "../../buttons/src/Button.vue.rd.js";
const h = {
  key: 0,
  class: "flex items-center pl-7 pr-5 py-5"
}, y = ["innerHTML"], k = /* @__PURE__ */ c("span", { class: "text-gray-700 text-lg i-ic:round-close dark:text-gray-300" }, null, -1), b = /* @__PURE__ */ a({
  __name: "ModalHeader",
  props: u(),
  emits: ["close"],
  setup(C, { emit: g }) {
    return (e, t) => e.showCloseIcon || e.headTitle || e.$slots.title ? (o(), l("div", h, [
      s(e.$slots, "default"),
      e.headTitle ? (o(), l("h2", {
        key: 0,
        class: i([{ "text-center": e.center }, "text-theme w-full font-bold m-0 h-fit-content text-lg text-heading text-opacity-70"]),
        innerHTML: e.headTitle
      }, null, 10, y)) : s(e.$slots, "title", { key: 1 }),
      e.showCloseIcon && !e.hoverableClose ? (o(), m(d(f), {
        key: 2,
        circle: "",
        icon: "",
        type: "outline",
        color: "neutro",
        class: "ml-auto !py-0 !px-0",
        onClick: t[0] || (t[0] = (n) => e.$emit("close"))
      }, {
        default: p(() => [
          k
        ]),
        _: 1
      })) : e.showCloseIcon && e.hoverableClose ? (o(), l("span", {
        key: 3,
        style: { "font-size": "1.2em" },
        class: "dark:text-gray-300 text-gray-500 hoverable-close ml-auto hover:text-gray-900 i-ic:round-close",
        onClick: t[1] || (t[1] = (n) => e.$emit("close"))
      })) : r("", !0)
    ])) : r("", !0);
  }
});
export {
  b as default
};

==> vue-components-1.5.40.tgz: package/lib/modals/src/ModalHeader.vue.rd.js <==
import { defineComponent as a, openBlock as o, createElementBlock as l, renderSlot as s, normalizeClass as i, createBlock as m, unref as d, withCtx as c, createCommentVNode as r, createElementVNode as p } from "vue";
import "../../buttons/index.rd.js";
import { modalHeaderProps as u } from "./props.rd.js";
import f from "../../buttons/src/Button.vue.rd.js";
const h = {
  key: 0,
  class: "flex items-center pl-7 pr-5 py-4"
}, y = ["innerHTML"], k = /* @__PURE__ */ p("span", { class: "text-gray-700 text-lg i-ic:round-close dark:text-gray-300" }, null, -1), b = /* @__PURE__ */ a({
  __name: "ModalHeader",
  props: u(),
  emits: ["close"],
  setup(C, { emit: g }) {
    return (e, t) => e.showCloseIcon || e.headTitle || e.$slots.title ? (o(), l("div", h, [
      s(e.$slots, "default"),
      e.headTitle ? (o(), l("h2", {
        key: 0,
        class: i([{ "text-center": e.center }, "text-theme max-w-full truncate w-full font-bold m-0 h-fit-content text-lg text-heading text-opacity-70"]),
        innerHTML: e.headTitle
      }, null, 10, y)) : s(e.$slots, "title", { key: 1 }),
      e.showCloseIcon && !e.hoverableClose ? (o(), m(d(f), {
        key: 2,
        circle: "",
        icon: "",
        type: "outline",
        color: "neutro",
        class: "ml-auto !py-0 !px-0",
        onClick: t[0] || (t[0] = (n) => e.$emit("close"))
      }, {
        default: c(() => [
          k
        ]),
        _: 1
      })) : e.showCloseIcon && e.hoverableClose ? (o(), l("span", {
        key: 3,
        style: { "font-size": "1.2em" },
        class: "dark:text-gray-300 text-gray-500 hoverable-close ml-auto hover:text-gray-900 i-ic:round-close",
        onClick: t[1] || (t[1] = (n) => e.$emit("close"))
      })) : r("", !0)
    ])) : r("", !0);
  }
});
export {
  b as default
};
